extern int *floor_tiles_list;
extern int *wall_tiles_list;
extern int *machinery_tiles_list;
extern int *furniture_tiles_list;
extern int *container_tiles_list;
extern int *nature_tiles_list;
extern int *misc_tiles_list;
extern int *waypoint_list;
extern int *sidewalk_floor_list;
extern int *water_floor_list;
extern int *grass_floor_list;
extern int *sand_floor_list;
extern int *square_floor_list;
extern int *other_floor_list;
extern int *melee_items_list;
extern int *gun_items_list;
extern int *defense_items_list;
extern int *spell_items_list;
extern int *other_items_list;
extern int *map_label_list;
extern int *all_items_list;
extern int *droid_enemies_list;
extern int *human_enemies_list;
extern int *all_enemies_list;

void lvledit_build_tile_lists(void);
void lvledit_set_obstacle_list_for_category(const char *category_name, struct dynarray *obstacle_list);
